Home
last modified time | relevance | path

Searched refs:__attribute__ (Results 1 – 25 of 1073) sorted by relevance

12345678910>>...43

/freebsd-13.1/contrib/llvm-project/clang/lib/Headers/
H A D__clang_hip_libdevice_declares.h18 __device__ __attribute__((const)) float __ocml_acos_f32(float);
19 __device__ __attribute__((pure)) float __ocml_acosh_f32(float);
20 __device__ __attribute__((const)) float __ocml_asin_f32(float);
21 __device__ __attribute__((pure)) float __ocml_asinh_f32(float);
141 __device__ inline __attribute__((const)) float
145 __device__ inline __attribute__((const)) float
149 __device__ inline __attribute__((const)) float
153 __device__ inline __attribute__((const)) float
280 __device__ inline __attribute__((const)) double
284 __device__ inline __attribute__((const)) double
[all …]
H A Darm_acle.h72 static __inline__ uint32_t __attribute__((__always_inline__, __nodebug__))
114 static __inline__ uint32_t __attribute__((__always_inline__, __nodebug__))
122 static __inline__ uint64_t __attribute__((__always_inline__, __nodebug__))
251 static __inline__ int32_t __attribute__((__always_inline__,__nodebug__))
255 static __inline__ int32_t __attribute__((__always_inline__,__nodebug__))
259 static __inline__ int32_t __attribute__((__always_inline__,__nodebug__))
263 static __inline__ int32_t __attribute__((__always_inline__,__nodebug__))
267 static __inline__ int32_t __attribute__((__always_inline__,__nodebug__))
271 static __inline__ int32_t __attribute__((__always_inline__,__nodebug__))
757 static __inline__ int __attribute__((__always_inline__, __nodebug__))
[all …]
H A Dhtmxlintrin.h37 __attribute__ ((__gnu_inline__, __always_inline__, __artificial__))
46 __attribute__ ((__gnu_inline__, __always_inline__, __artificial__))
63 __attribute__ ((__gnu_inline__, __always_inline__, __artificial__))
72 __attribute__ ((__gnu_inline__, __always_inline__, __artificial__))
79 __attribute__ ((__gnu_inline__, __always_inline__, __artificial__))
86 __attribute__ ((__gnu_inline__, __always_inline__, __artificial__))
93 __attribute__ ((__gnu_inline__, __always_inline__, __artificial__))
100 __attribute__ ((__gnu_inline__, __always_inline__, __artificial__))
108 __attribute__ ((__gnu_inline__, __always_inline__, __artificial__))
118 __attribute__ ((__gnu_inline__, __always_inline__, __artificial__))
[all …]
H A Dopencl-c-base.h108 typedef char char2 __attribute__((ext_vector_type(2)));
109 typedef char char3 __attribute__((ext_vector_type(3)));
110 typedef char char4 __attribute__((ext_vector_type(4)));
128 typedef int int2 __attribute__((ext_vector_type(2)));
129 typedef int int3 __attribute__((ext_vector_type(3)));
130 typedef int int4 __attribute__((ext_vector_type(4)));
131 typedef int int8 __attribute__((ext_vector_type(8)));
578 __attribute__((work_group_size_hint(X, 1, 1))) \
579 __attribute__((vec_type_hint(typen)))
582 __attribute__((work_group_size_hint(X, 1, 1))) \
[all …]
H A D__clang_hip_runtime_wrapper.h21 #define __host__ __attribute__((host))
22 #define __device__ __attribute__((device))
23 #define __global__ __attribute__((global))
24 #define __shared__ __attribute__((shared))
26 #define __managed__ __attribute__((managed))
34 __attribute__((__visibility__("default")))
35 __attribute__((weak))
36 __attribute__((noreturn))
40 __attribute__((__visibility__("default")))
41 __attribute__((weak))
[all …]
H A D__clang_cuda_builtin_vars.h50 __attribute__((device)) TypeName *operator&() const __DELETE
58 __attribute__((device)) operator dim3() const;
59 __attribute__((device)) operator uint3() const;
71 __attribute__((device)) operator dim3() const;
72 __attribute__((device)) operator uint3() const;
84 __attribute__((device)) operator dim3() const;
85 __attribute__((device)) operator uint3() const;
97 __attribute__((device)) operator dim3() const;
98 __attribute__((device)) operator uint3() const;
105 extern const __attribute__((device)) __attribute__((weak))
[all …]
H A Dimmintrin.h258 static __inline__ int __attribute__((__always_inline__, __nodebug__, __target__("rdrnd")))
264 static __inline__ int __attribute__((__always_inline__, __nodebug__, __target__("rdrnd")))
271 static __inline__ int __attribute__((__always_inline__, __nodebug__, __target__("rdrnd")))
346 } __attribute__((__packed__, __may_alias__)); in _loadbe_i16()
354 } __attribute__((__packed__, __may_alias__)); in _storebe_i16()
358 static __inline__ int __attribute__((__always_inline__, __nodebug__, __target__("movbe")))
362 } __attribute__((__packed__, __may_alias__)); in _loadbe_i32()
370 } __attribute__((__packed__, __may_alias__)); in _storebe_i32()
379 } __attribute__((__packed__, __may_alias__)); in _loadbe_i64()
387 } __attribute__((__packed__, __may_alias__)); in _storebe_i64()
[all …]
/freebsd-13.1/sys/netgraph/bluetooth/include/
H A Dng_hci.h414 } __attribute__ ((packed)) ng_hci_cmd_pkt_t;
441 } __attribute__ ((packed)) ng_hci_event_pkt_t;
446 } __attribute__ ((packed)) bdaddr_t;
455 } __attribute__ ((packed)) ng_hci_status_rp;
701 } __attribute__ ((packed)) ng_hci_inquiry_cp;
738 } __attribute__ ((packed)) ng_hci_discon_cp;
815 } __attribute__ ((packed)) ng_hci_auth_req_cp;
995 } __attribute__ ((packed)) ng_hci_flush_cp;
1000 } __attribute__ ((packed)) ng_hci_flush_rp;
1709 }__attribute__ ((packed)) ng_hci_le_rand_rp;
[all …]
/freebsd-13.1/crypto/openssh/openbsd-compat/
H A Dsha2.h80 __attribute__((__bounded__(__string__,2,3)));
83 __attribute__((__bounded__(__minbytes__,1,SHA224_DIGEST_LENGTH)));
91 __attribute__((__bounded__(__string__,1,2)))
99 __attribute__((__bounded__(__string__,2,3)));
110 __attribute__((__bounded__(__string__,1,2)))
118 __attribute__((__bounded__(__string__,2,3)));
129 __attribute__((__bounded__(__string__,1,2)))
137 __attribute__((__bounded__(__string__,2,3)));
148 __attribute__((__bounded__(__string__,1,2)))
156 __attribute__((__bounded__(__string__,2,3)));
[all …]
H A Dmd5.h32 __attribute__((__bounded__(__string__,2,3)));
35 __attribute__((__bounded__(__minbytes__,1,MD5_DIGEST_LENGTH)));
37 __attribute__((__bounded__(__minbytes__,1,4)))
38 __attribute__((__bounded__(__minbytes__,2,MD5_BLOCK_LENGTH)));
40 __attribute__((__bounded__(__minbytes__,2,MD5_DIGEST_STRING_LENGTH)));
42 __attribute__((__bounded__(__minbytes__,2,MD5_DIGEST_STRING_LENGTH)));
44 __attribute__((__bounded__(__minbytes__,2,MD5_DIGEST_STRING_LENGTH)));
46 __attribute__((__bounded__(__string__,1,2)))
47 __attribute__((__bounded__(__minbytes__,3,MD5_DIGEST_STRING_LENGTH)));
/freebsd-13.1/sys/contrib/openzfs/module/zcommon/
H A Dzfs_fletcher_aarch64_neon.c137 unsigned char ZERO __attribute__((vector_size(16))); in fletcher_4_aarch64_neon_native()
138 unsigned char ACC0 __attribute__((vector_size(16))); in fletcher_4_aarch64_neon_native()
139 unsigned char ACC1 __attribute__((vector_size(16))); in fletcher_4_aarch64_neon_native()
140 unsigned char ACC2 __attribute__((vector_size(16))); in fletcher_4_aarch64_neon_native()
141 unsigned char ACC3 __attribute__((vector_size(16))); in fletcher_4_aarch64_neon_native()
142 unsigned char TMP1 __attribute__((vector_size(16))); in fletcher_4_aarch64_neon_native()
143 unsigned char TMP2 __attribute__((vector_size(16))); in fletcher_4_aarch64_neon_native()
144 unsigned char SRC __attribute__((vector_size(16))); in fletcher_4_aarch64_neon_native()
176 unsigned char ZERO __attribute__((vector_size(16))); in fletcher_4_aarch64_neon_byteswap()
177 unsigned char ACC0 __attribute__((vector_size(16))); in fletcher_4_aarch64_neon_byteswap()
[all …]
/freebsd-13.1/contrib/llvm-project/clang/lib/Headers/ppc_wrappers/
H A Demmintrin.h58 typedef long long __m128i __attribute__ ((__vector_size__ (16), __may_alias__));
59 typedef double __m128d __attribute__ ((__vector_size__ (16), __may_alias__));
69 extern __inline __m128d __attribute__((__gnu_inline__, __always_inline__, __artificial__))
169 extern __inline void __attribute__((__gnu_inline__, __always_inline__, __artificial__))
176 extern __inline void __attribute__((__gnu_inline__, __always_inline__, __artificial__))
183 extern __inline void __attribute__((__gnu_inline__, __always_inline__, __artificial__))
195 extern __inline void __attribute__((__gnu_inline__, __always_inline__, __artificial__))
202 extern __inline void __attribute__((__gnu_inline__, __always_inline__, __artificial__))
209 extern __inline void __attribute__((__gnu_inline__, __always_inline__, __artificial__))
215 extern __inline void __attribute__((__gnu_inline__, __always_inline__, __artificial__))
[all …]
H A Dxmmintrin.h65 typedef vector float __m128 __attribute__((__may_alias__));
68 typedef vector float __m128_u __attribute__((__may_alias__, __aligned__(1)));
74 extern __inline __m128 __attribute__((__gnu_inline__, __always_inline__, __artificial__))
82 extern __inline __m128 __attribute__((__gnu_inline__, __always_inline__, __artificial__))
89 extern __inline __m128 __attribute__((__gnu_inline__, __always_inline__, __artificial__))
145 extern __inline void __attribute__((__gnu_inline__, __always_inline__, __artificial__))
152 extern __inline void __attribute__((__gnu_inline__, __always_inline__, __artificial__))
159 extern __inline void __attribute__((__gnu_inline__, __always_inline__, __artificial__))
173 extern __inline void __attribute__((__gnu_inline__, __always_inline__, __artificial__))
180 extern __inline void __attribute__((__gnu_inline__, __always_inline__, __artificial__))
[all …]
H A Dmmintrin.h43 typedef __attribute__((__aligned__(8))) unsigned long long __m64;
45 typedef __attribute__((__aligned__(8))) union {
58 __attribute__((__gnu_inline__, __always_inline__, __artificial__))
64 __attribute__((__gnu_inline__, __always_inline__, __artificial__))
71 __attribute__((__gnu_inline__, __always_inline__, __artificial__))
77 __attribute__((__gnu_inline__, __always_inline__, __artificial__))
84 __attribute__((__gnu_inline__, __always_inline__, __artificial__))
90 __attribute__((__gnu_inline__, __always_inline__, __artificial__))
99 __attribute__((__gnu_inline__, __always_inline__, __artificial__))
105 __attribute__((__gnu_inline__, __always_inline__, __artificial__))
[all …]
/freebsd-13.1/sys/contrib/openzfs/module/zfs/
H A Dvdev_raidz_math_powerpc_altivec_common.h622 unsigned char w3 __attribute__((vector_size(16)));
625 unsigned char w5 __attribute__((vector_size(16)));
628 unsigned char w7 __attribute__((vector_size(16)));
631 unsigned char w9 __attribute__((vector_size(16)));
634 unsigned char w11 __attribute__((vector_size(16)));
639 unsigned char w15 __attribute__((vector_size(16)));
641 unsigned char w16 __attribute__((vector_size(16)));
643 unsigned char w17 __attribute__((vector_size(16)));
648 unsigned char w21 __attribute__((vector_size(16)));
651 unsigned char w23 __attribute__((vector_size(16)));
[all …]
H A Dvdev_raidz_math_aarch64_neon_common.h616 unsigned char w3 __attribute__((vector_size(16)));
619 unsigned char w5 __attribute__((vector_size(16)));
622 unsigned char w7 __attribute__((vector_size(16)));
625 unsigned char w9 __attribute__((vector_size(16)));
628 unsigned char w11 __attribute__((vector_size(16)));
633 unsigned char w15 __attribute__((vector_size(16)));
635 unsigned char w16 __attribute__((vector_size(16)));
637 unsigned char w17 __attribute__((vector_size(16)));
642 unsigned char w21 __attribute__((vector_size(16)));
645 unsigned char w23 __attribute__((vector_size(16)));
[all …]
/freebsd-13.1/contrib/apr/include/
H A Dapr_pools.h382 __attribute__((nonnull(1)));
412 __attribute__((nonnull(1)));
434 __attribute__((nonnull(1)));
449 __attribute__((nonnull(1)));
478 __attribute__((nonnull(1)));
500 __attribute__((nonnull(2)));
537 __attribute__((nonnull(1)));
632 __attribute__((nonnull(3,4)));
649 __attribute__((nonnull(3)));
665 __attribute__((nonnull(3)));
[all …]
H A Dapr_allocator.h75 __attribute__((nonnull(1)));
84 __attribute__((nonnull(1)));
94 __attribute__((nonnull(1)));
105 __attribute__((nonnull(1,2)));
132 __attribute__((nonnull(1)));
139 __attribute__((nonnull(1)));
149 __attribute__((nonnull(1)));
161 __attribute__((nonnull(1)));
169 __attribute__((nonnull(1)));
/freebsd-13.1/sys/dev/pms/freebsd/driver/common/
H A Dencrypt_ioctl.h51 } __attribute__ ((packed)) IoctlEncryptGetInfo_t;
55 } __attribute__ ((packed)) IoctlEncryptSetMode_t;
62 } __attribute__ ((packed)) IoctlEncryptKekAdd_t;
71 } __attribute__ ((packed)) IoctlEncryptDekAdd_t;
79 } __attribute__ ((packed)) IoctlEncryptKekNVRAM_t;
93 } __attribute__ ((packed)) EncryptDekMapEntry_t;
103 } __attribute__ ((packed)) EncryptDeviceDekMap_t;
124 } __attribute__ ((packed)) IoctlEncryptIOError_t;
142 } __attribute__ ((packed)) IoctlEncryptOp_t;
168 } __attribute__ ((packed)) IoctlTISAEncrypt_t;
[all …]
/freebsd-13.1/tools/build/cross-build/include/common/sys/
H A Dcdefs.h63 #define __pure __attribute__((__pure__))
66 #define __packed __attribute__((__packed__))
69 #define __dead2 __attribute__((__noreturn__))
72 #define __pure2 __attribute__((__const__))
75 #define __used __attribute__((__used__))
78 #define __aligned(x) __attribute__((__aligned__(x)))
81 #define __section(x) __attribute__((__section__(x)))
113 #define __weak_symbol __attribute__((__weak__))
122 static int alias() __attribute__((weakref(#sym)));
139 #define __malloc_like __attribute__((__malloc__))
[all …]
/freebsd-13.1/sys/sys/
H A Dcdefs.h202 #define __weak_symbol __attribute__((__weak__))
209 #define __dead2 __attribute__((__noreturn__))
210 #define __pure2 __attribute__((__const__))
215 #define __dead2 __attribute__((__noreturn__))
216 #define __pure2 __attribute__((__const__))
217 #define __unused __attribute__((__unused__))
218 #define __used __attribute__((__used__))
219 #define __packed __attribute__((__packed__))
345 #define __pure __attribute__((__pure__))
364 #define __fastcall __attribute__((__fastcall__))
[all …]
/freebsd-13.1/crypto/openssh/
H A Dmisc.h82 __attribute__((__format__ (printf, 3, 4))) __attribute__((__nonnull__ (3)));
122 __attribute__((format(printf, 2, 3)));
124 __attribute__((format(printf, 3, 4)));
145 __attribute__((__bounded__( __minbytes__, 1, 8)));
147 __attribute__((__bounded__( __minbytes__, 1, 4)));
149 __attribute__((__bounded__( __minbytes__, 1, 2)));
151 __attribute__((__bounded__( __minbytes__, 1, 8)));
159 __attribute__((__bounded__(__minbytes__, 1, 4)));
161 __attribute__((__bounded__(__minbytes__, 1, 4)));
221 __attribute__((format(printf, 2, 3)));
[all …]
/freebsd-13.1/contrib/libcxxrt/
H A Dmemory.cc61 __attribute__((weak))
66 __attribute__((weak))
83 __attribute__((weak))
108 __attribute__((weak))
121 __attribute__((weak))
128 __attribute__((weak))
135 __attribute__((weak))
148 __attribute__((weak))
158 __attribute__((weak))
165 __attribute__((weak))
/freebsd-13.1/contrib/llvm-project/libunwind/src/
H A DUnwind_AppleExtras.cpp17 __attribute__((visibility("default"))) const char sym##_tmp30 = 0; \
19 __attribute__((visibility("default"))) const char sym##_tmp31 = 0; \
21 __attribute__((visibility("default"))) const char sym##_tmp32 = 0; \
23 __attribute__((visibility("default"))) const char sym##_tmp40 = 0; \
25 __attribute__((visibility("default"))) const char sym##_tmp41 = 0; \
27 __attribute__((visibility("default"))) const char sym##_tmp42 = 0; \
29 __attribute__((visibility("default"))) const char sym##_tmp43 = 0;
36 __attribute__((visibility("default"))) const char sym##_tmp4 = 0; \
38 __attribute__((visibility("default"))) const char sym##_tmp5 = 0;
41 __attribute__((visibility("default"))) const char sym##_tmp4 = 0; \
[all …]
/freebsd-13.1/contrib/llvm-project/compiler-rt/lib/crt/
H A Dcrtbegin.c11 __attribute__((visibility("hidden"))) void *__dso_handle = &__dso_handle;
15 __attribute__((section(".eh_frame"), aligned(sizeof(void *)))) = {};
17 extern void __register_frame_info(const void *, void *) __attribute__((weak));
18 extern void *__deregister_frame_info(const void *) __attribute__((weak));
25 __attribute__((section(".ctors"), aligned(sizeof(fp)))) = {(fp)-1};
29 extern void __cxa_finalize(void *) __attribute__((weak));
31 static void __attribute__((used)) __do_init() { in __do_init()
49 __attribute__((section(".init_array"),
78 __attribute__((section(".dtors"), aligned(sizeof(fp)))) = {(fp)-1};
82 static void __attribute__((used)) __do_fini() { in __do_fini()
[all …]

12345678910>>...43